==> end_of_file-0.0.1-py3-none-any.whl: end_of_file/__init__.py <==
import logging
import re
import click
from pathlib import Path
from typing import List, Generator, Optional, Callable, TextIO
import os


def walker(
    path: Path,
    is_interesting: Callable[[Path], bool],
) -> Generator[Path, None, None]:
    for root, dirs, files in os.walk(path):
        files = [f for f in files if not f[0] == "."]
        dirs[:] = [d for d in dirs if not d[0] == "."]

        for name in files:
            filepath = Path(root).joinpath(name)
            if is_interesting(filepath):
                yield filepath


def validate_extensions(ctx, param, value):
    if not value:
        return value

    regex = r"[a-zA-Z0-9,]"
    if not re.match(regex, value):
        raise click.BadParameter(
            f"Extensions parameter must match following regex: '{regex}', got '{value}'."
        )

    return value.split(",")


def bruteforce(path: Path) -> bool:
    try:
        with open(path, "r") as f:
            f.readline()
            return True

    except UnicodeDecodeError:
        return False


def mimetype(path: Path) -> bool:
    import mimetypes

    mimetype, encoding = mimetypes.guess_type(path)
    return mimetype and mimetype.startswith("text")


def build_validator(
    extensions: Optional[List[str]],
    strategy: str,
) -> Callable[[Path], bool]:
    if extensions:
        return lambda path: path.suffix.lower()[1:] in extensions

    if strategy == "bruteforce":
        return bruteforce

    if strategy == "mimetype":
        return mimetype

    raise Exception(
        f"Please provide extensions list or valid strategy. Provided extensions: {extensions}, strategy: {strategy}."
    )


def lint_file(handle: TextIO, check: bool) -> bool:
    content = handle.read()

    if not content:
        return True

    count = 0
    for tail in reversed(content):
        if tail == "\n":
            count += 1

        else:
            break

    if count == 1:
        return True

    if check:
        return False

    elif count == 0:
        handle.write("\n")
        return False

    elif count > 1:
        handle.seek(len(content) - count + 1)
        handle.truncate()
        return False

    else:
        raise Exception(f"No idea what happened, count: '{count}'.")


@click.command()
@click.option(
    "-p",
    "--path",
    required=True,
    default=Path("."),
    help="Root of the project, folder will be traversed.",
    show_default=True,
)
@click.option(
    "-e",
    "--extensions",
    help="Comma separated list of extensions or nothing",
    callback=validate_extensions,
)
@click.option(
    "-c",
    "--check",
    help="Reports misformatted files and exits with error",
    is_flag=True,
    default=False,
)
@click.option(
    "-s",
    "--strategy",
    help="Strategy used to determine if file is text file in case extensions are not provided.",
    type=click.Choice(["bruteforce", "mimetype"], case_sensitive=False),
    default="bruteforce",
    show_default=True,
)
def lint(path: Path, extensions: Optional[List[str]], check: bool, strategy: str):
    errors = []
    for filepath in walker(path, build_validator(extensions, strategy)):
        with open(filepath, "r+") as f:
            logging.info(f"Checking file: {filepath}.")
            if not lint_file(f, check):
                errors.append(filepath)

    for error in errors:
        logging.info(f"Found misformatted file {error}.")

    if check and errors:
        exit(1)


if __name__ == "__main__":
    logging.getLogger().setLevel(logging.DEBUG)
    lint()

==> end_of_file-1.0.0-py3-none-any.whl: end_of_file/__init__.py <==
import logging
import re
import click
from pathlib import Path
from typing import List, Generator, Optional, Callable, TextIO
import os


logging.basicConfig(level=logging.INFO)
logger = logging.getLogger("eof")
logger.setLevel(logging.INFO)


def walker(
    path: Path,
    is_interesting: Callable[[Path], bool],
) -> Generator[Path, None, None]:
    for root, dirs, files in os.walk(path):
        files = [f for f in files if not f[0] == "."]
        dirs[:] = [d for d in dirs if not d[0] == "."]

        for name in files:
            filepath = Path(root).joinpath(name)
            if is_interesting(filepath):
                yield filepath


def validate_extensions(ctx, param, value):
    if not value:
        return value

    regex = r"^[a-zA-Z0-9,]+$"
    if not re.match(regex, value):
        raise click.BadParameter(
            f"Extensions parameter must match following regex: '{regex}', got '{value}'."
        )

    return value.split(",")


def bruteforce(path: Path) -> bool:
    try:
        with open(path, "r") as f:
            f.readline()
            return True

    except UnicodeDecodeError:
        return False


def mimetype(path: Path) -> bool:
    import mimetypes

    mimetype, encoding = mimetypes.guess_type(path)
    return mimetype and mimetype.startswith("text")


def build_validator(
    extensions: Optional[List[str]],
    strategy: str,
) -> Callable[[Path], bool]:
    if extensions:
        return lambda path: path.suffix.lower()[1:] in extensions

    if strategy == "bruteforce":
        return bruteforce

    if strategy == "mimetype":
        return mimetype

    raise Exception(
        f"Please provide extensions list or valid strategy. Provided extensions: {extensions}, strategy: {strategy}."
    )


def format_file(handle: TextIO, check: bool) -> bool:
    content = handle.read()

    if not content:
        return True

    count = 0
    for tail in reversed(content):
        if tail in ["\n", " ", "\t"]:
            count += 1

        else:
            break

    if count == 1:
        return True

    if check:
        return False

    elif count == 0:
        handle.write("\n")
        return False

    elif count > 1:
        handle.seek(len(content) - count)
        handle.truncate()
        handle.write("\n")
        return False

    else:
        raise Exception(f"No idea what happened, count: '{count}'.")


@click.command()
@click.option(
    "-p",
    "--path",
    required=True,
    default=Path("."),
    help="Root of the project, folder will be traversed.",
    show_default=True,
)
@click.option(
    "-e",
    "--extensions",
    help="Comma separated list of extensions or nothing",
    callback=validate_extensions,
)
@click.option(
    "-c",
    "--check",
    help="Reports malformatted files and exits with error",
    is_flag=True,
    default=False,
)
@click.option(
    "-s",
    "--strategy",
    help="Strategy used to determine if file is text file in case extensions are not provided.",
    type=click.Choice(["bruteforce", "mimetype"], case_sensitive=False),
    default="bruteforce",
    show_default=True,
)
def format(path: Path, extensions: Optional[List[str]], check: bool, strategy: str):
    errors = []
    for filepath in walker(path, build_validator(extensions, strategy)):
        with open(filepath, "r+") as f:
            logger.info(f"Checking file: '{filepath}'.")
            if not format_file(f, check):
                errors.append(filepath)

    for error in errors:
        logger.info(f"Found malformatted file '{error}'.")

    if check and errors:
        exit(1)


if __name__ == "__main__":
    format()
